@@ -1,2 +1,2 @@
 from .img_converter import colorize, numpy_to_b64, pil_to_b64
-from .utils import which_fired
+from .utils import which_fired, GlobalData
